@@ -2,7 +2,34 @@
 
 # Notification Center code borrowed from https://github.com/maranas/pyNotificationCenter/blob/master/pyNotificationCenter.py
 
-import os, sys, json, re, hashlib, argparse
+import os, sys, json, re, hashlib, argparse, urllib, time
+
+# check for updates
+GIST_URL        =   'https://api.github.com/gists/5317321'
+CHECK_FILE      =   os.path.expanduser('~/.d3ploy-update-check')
+if not os.path.exists(CHECK_FILE):
+    try:
+        open(CHECK_FILE, 'w')
+    except IOError:
+        pass
+try:
+    last_checked    =   int(open(CHECK_FILE, 'r').read().strip())
+except ValueError:
+    last_checked    =   0
+now =   int(time.time())
+if now - last_checked > 86400:
+    # it has been a day since the last update check
+    try:
+        gist_hash       =   hashlib.md5(json.load(urllib.urlopen(GIST_URL)).get('files').get('d3ploy.py').get('content')).hexdigest()
+        script_hash     =   hashlib.md5(open(__file__, 'r').read()).hexdigest()
+        check_file      =   open(CHECK_FILE, 'w')
+        check_file.write('%d' % now)
+        check_file.flush()
+        check_file.close()
+        if not gist_hash == script_hash:
+            print 'There has been an update for d3ploy.\nPlease see https://gist.github.com/dryan/5317321 or run `pip install --upgrade d3ploy`.\n'
+    except:
+        pass
 
 try:
     import boto
@@ -35,17 +62,29 @@ def notify(env, text):
         notification.setSoundName_("NSUserNotificationDefaultSoundName")
         notification.setDeliveryDate_(Foundation.NSDate.dateWithTimeInterval_sinceDate_(0, Foundation.NSDate.date()))
         NSUserNotificationCenter.defaultUserNotificationCenter().scheduleNotification_(notification)
+        
+# load the config file for this folder
+try:
+    config      =   open('deploy.json', 'r')
+except IOError:
+    if __name__ == "__main__":
+        print "deploy.json file is missing. See https://gist.github.com/dryan/5317321 for more information."
+    sys.exit(os.EX_NOINPUT)
+
+config          =   json.load(config)
+
+environments    =   [str(item) for item in config.keys()]
     
 valid_acls      =   ["private", "public-read", "public-read-write", "authenticated-read"]
 
 parser          =   argparse.ArgumentParser()
-parser.add_argument('environment', help = "Which environment to deploy to", nargs = "?", type = str, default = "default",)
+parser.add_argument('environment', help = "Which environment to deploy to", nargs = "?", type = str, default = "default", choices = environments)
 parser.add_argument('-a', '--access-key', help = "AWS Access Key ID", type = str)
 parser.add_argument('-s', '--access-secret', help = "AWS Access Key Secret", type = str)
 parser.add_argument('-f', '--force', help = "Upload all files whether they are currently up to date on S3 or not", action = "store_true", default = False)
 parser.add_argument('--all', help = "Upload to all environments", action = "store_true", default = False)
 parser.add_argument('-n', '--dry-run', help = "Show which files would be updated without uploading to S3", action = "store_true", default = False)
-parser.add_argument('--acl', help = "The ACL to apply to uploaded files. Must be one of: %s" % ' '.join(valid_acls), type = str, default = "public-read",)
+parser.add_argument('--acl', help = "The ACL to apply to uploaded files.", type = str, default = "public-read", choices = valid_acls)
 
 args            =   parser.parse_args()
 
@@ -162,16 +201,6 @@ def upload_files(env, config):
     if __name__ == "__main__":
         print ""
 
-# load the config file for this folder
-try:
-    config          =   open('deploy.json', 'r')
-except IOError:
-    if __name__ == "__main__":
-        print "deploy.json file is missing. See https://gist.github.com/dryan/5317321 for more information."
-    sys.exit(os.EX_NOINPUT)
-
-config              =   json.load(config)
-
 if not args.environment in config:
     if __name__ == "__main__":
         print 'The "%s" environment was not found in deploy.json' % args.environment
